==> neompy-et-0.0.9.tar.gz: neompy-et-0.0.9/neom/new_ddd/shared_/abstract_specification.py <==
# Copyright 2022 neomadas-dev
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   3. Neither the name of the copyright holder nor the names of its
#      contributors may be used to endorse or promote products derived from
#      this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""Abstract specification module."""

from __future__ import annotations

from typing import Final, TypeVar

from .specification import Specification

__all__ = ('AbstractSpecification',)

T = TypeVar('T')


class AbstractSpecification(Specification[T]):
  """Base of composite ``Specification`` with ``and``, ``or`` and ``not``
  default implementations."""

  def And(self, specification: Final[Specification[T]]) -> Specification[T]:
    from .and_specification import AndSpecification  # pylint:disable=C0415
    return AndSpecification(self, specification)

  def Or(self, specification: Final[Specification[T]]) -> Specification[T]:
    from .or_specification import OrSpecification  # pylint:disable=C0415
    return OrSpecification(self, specification)

  def Not(self, specification: Final[Specification[T]]) -> Specification[T]:
    from .not_specification import NotSpecification  # pylint:disable=C0415
    return NotSpecification(specification)

==> neompy-et-0.0.16.tar.gz: neompy-et-0.0.16/neom/new_ddd/shared_/abstract_specification.py <==
# Copyright 2022 neomadas-dev
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   3. Neither the name of the copyright holder nor the names of its
#      contributors may be used to endorse or promote products derived from
#      this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""Abstract specification module."""

from __future__ import annotations

from typing import Final, TypeVar

from .specification import Specification

__all__ = ("AbstractSpecification",)

T = TypeVar("T")


class AbstractSpecification(Specification[T]):
    """Base of composite ``Specification`` with ``and``, ``or`` and ``not``
    default implementations."""

    def And(self, specification: Final[Specification[T]]) -> Specification[T]:
        from .and_specification import AndSpecification  # pylint:disable=C0415

        return AndSpecification(self, specification)

    def Or(self, specification: Final[Specification[T]]) -> Specification[T]:
        from .or_specification import OrSpecification  # pylint:disable=C0415

        return OrSpecification(self, specification)

    def Not(self) -> Specification[T]:
        from .not_specification import NotSpecification  # pylint:disable=C0415

        return NotSpecification(self)
